@@ -73,9 +73,9 @@ class OriOptimizeEnv(gym.Env):
     def _get_info(self):
         """info信息与观察值不同，info信息是深层次的模型信息，比如模型方向的具体数字"""
 
-        return {"orientation": self._agent_orientation}  # 暂时没什么info需要返回
+        return {"info": self._agent_orientation}  # 暂时没什么info需要返回
 
-    def _get_obs(self, img=torch.tensor((227, 227, 3))):
+    def _get_obs(self, img=np.ones((227, 227, 3), dtype=np.float32)):
         """获得观察值，即图片，应从OpenGL的程序中得到，目前还没放入接口"""
 
         new_obs = np.moveaxis(img, 2, 0)  # 一般输入的图片的通道就是227x227x3, 调整227x227x3的通道为3x227x227
@@ -88,11 +88,11 @@ class OriOptimizeEnv(gym.Env):
 
         super().reset(seed=seed)
         self._agent_orientation = self.initial_ori  # 重置环境其实就是将模型的角度摆正，摆回原来的位置
-        self.env.getInitialOri(self.initial_ori)
+        self.env.getInitialOri(self.initial_ori[0], self.initial_ori[1], self.initial_ori[2])
         self.current_support_volume = self.env.runCompute()
         observation = self._get_obs()
         info = self._get_info()
-
+        print("reset success")
         # if self.render_mode == "human":
         #     self._render_frame()
 
@@ -105,14 +105,15 @@ class OriOptimizeEnv(gym.Env):
         angle = self._action_to_direction[action]
         self._agent_orientation = self._agent_orientation.dot(angle)  # 乘上一个旋转矩阵以后就是新的模型朝向方向了
 
-        self.env.getOri(self._agent_orientation)
+        self.env.getOri(self._agent_orientation[0], self._agent_orientation[1], self._agent_orientation[2])
         support_area = self.env.runCompute()
         reward = (self.current_support_volume - support_area) / self.current_support_volume  # 暂定将奖励设计成减少的体积百分比
         terminated = np.array_equal(self._agent_orientation, self._target_orientation)  # 是否结束
         reward += -0.05 if not terminated else 0  # 如果结束获得奖励，未结束的时候获得的奖励不能为0，应该为负，避免模型停在原地不动
 
-        observation = self._get_obs()
-        info = self._get_info()
+        _, observation = self._get_obs()
+        _, info = self._get_info()
+        print("step forward")
 
         return observation, reward, terminated, False, info
 
